"""
TestSplitURL program contains python unit test codes which test a python method which splits
URL into their components. The python function takes a string a input parameter and returns a
list containing the URL components - Protocol String, Server Name, Path and Arguments if any.

    Program Name:     TestSplitURL.py
    Developer:        redacted
    Python:           v3.4
    Date:             Feb 9 2015
    Required Include: spliturl.py
"""

import unittest
import spliturl

class URLSplitTest(unittest.TestCase):
    """
    URLSplitTest Class is defined to manage all the unit test cases. The unittest module provides
    a rich set of tools for constructing and running tests.
    """

    def testInputType(self):
        """
        Function to test for String type input data
        """
        try:
            self.failIf(spliturl.GetURLComponents(999.231))
        except:
            pass

    def testValidShortURL(self):
        """
        Function to test for valid short url without any path or arguments
        """
        validURLComp = ["http", "www.weather.com", "", ""]
        self.assertEqual(spliturl.GetURLComponents("http://www.weather.com"),validURLComp)

    def testValidIPUrl(self):
        """
        Function to test a valid IP based URL
        """
        validIpUrlComp = ["http", "74.125.225.18","",""]
        self.assertEqual(spliturl.GetURLComponents("http://74.125.225.18"),validIpUrlComp)

    def testInvalidShortURL(self):
        """
        Function to test a short url with incorrect syntax
        """
        invalidURLComp = ["http","www.google.com", "/index", ""]
        self.assertNotEqual(spliturl.GetURLComponents("http:\\www.google.com/index"), invalidURLComp)

    def testUrlWithPath(self):
        """
        Function to test for an URL with path and without any arguments
        """
        URLCompWithPath = ["http","www.bridgew.edu", "/academics/graduate-studies/master-science-computer-science", ""]
        self.assertEqual(spliturl.GetURLComponents("http://www.bridgew.edu/academics/graduate-studies/master-science-computer-science"),URLCompWithPath)

    def testUrlWithArgs(self):
        """
        Function to test an URL containing path and argument components and also a Secure URL
        """
        URLCompWithArgs = ["http", "www.amazon.com", "/s/ref=nb_sb_noss","url=search-alias%3Daps&field-keywords=clean+code" ]
        self.assertEqual(spliturl.GetURLComponents("http://www.amazon.com/s/ref=nb_sb_noss?url=search-alias%3Daps&field-keywords=clean+code"),URLCompWithArgs)

        SecureURLCompWithArgs = ["https", "www.bankofamerica.com", "/search/Search.go", "questionbox=cash+back&searchSourceSite=dotcom&searchSourceDir=credit-cards&searchSourceTitle=View+All+Credit+Cards&locale=en_US"]
        self.assertEqual(spliturl.GetURLComponents("https://www.bankofamerica.com/search/Search.go?questionbox=cash+back&searchSourceSite=dotcom&searchSourceDir=credit-cards&searchSourceTitle=View+All+Credit+Cards&locale=en_US"), SecureURLCompWithArgs)

    def testInvalidURLs(self):
        """
        Function to test Malformed URLs, incorrect syntax or URL formats not supported by the GetURLComponents method.
        """
        ZeroItemList = [] #Empty List
        self.assertEqual(spliturl.GetURLComponents("htp:go.antadesd/ase;1234::test"),ZeroItemList)
        self.assertEqual(spliturl.GetURLComponents("https::://www.bestbuy:com/site:mobile-cell-phones/iphone/pcmcat305200050000.c?id=pcmcat305200050000"),ZeroItemList)
        self.assertEqual(spliturl.GetURLComponents("mailto:testmail@test.com"),ZeroItemList)

    def testFTPLink(self):
        """
        Function to test FTP links
        """
        ftpComponents = ["ftp", "example.com", "/pub/file.txt", ""]
        self.assertEqual(spliturl.GetURLComponents("ftp://example.com/pub/file.txt"), ftpComponents)

    def testValidLocalhostURL(self):
        """
        Function to test a localhost URL
        """
        localhostURLComp = ["http", "localhost:8888", "/install.folder", ""]
        self.assertEqual(spliturl.GetURLComponents("http://localhost:8888/install.folder"),localhostURLComp)

if __name__ == '__main__':
    unittest.main()
