__author__ = 'redacted'

import unittest
import web_crawler as crawler

class SplitTests(unittest.TestCase):
    '''
    Write a unit test code to test a python method which will split URLs into their pieces
    The function will take a string as a parameter, it should return the following:
    A list with: The protocol string, the server name, the path, and any arguments (possibly empty).
    Malformed URLs will return an empty list
    '''
    def test_type_parameter(self):
        # basic types
        self.assertRaises(TypeError,crawler.split_url, 5)
        self.assertRaises(TypeError,crawler.split_url, False)
        self.assertRaises(TypeError,crawler.split_url, [])
        self.assertRaises(TypeError,crawler.split_url, {})

        # No error on string parameter
        error_flag = True # assume error hit
        try:
            crawler.split_url("Some String")
            error_flag = False
        except TypeError:
            error_flag = True
        self.assertEqual(error_flag, False)

    def test_malformed_query(self):
        result = crawler.split_url("malformedURL")
        self.assertIsInstance(result, list)
        self.assertEqual(len(result), 0)

        # invalid url
        result = crawler.split_url('http:///demo/appl?input=3')
        self.assertIsInstance(result, list)
        self.assertEqual(len(result), 0)

        # invalid url, as defined by our specs
        result = crawler.split_url('www.makeit.org/demo/appl?input=3')
        self.assertIsInstance(result, list)
        self.assertEqual(len(result), 0)


    def test_small_successful_query(self):
        result = crawler.split_url('http://www.makeit.org/demo/appl?input=3')
        self.assertIsInstance(result, list) # Successful queries should also return a list
        self.assertEqual(len(result), 4)
        self.assertEqual(result[0], "http") # Protocol
        self.assertEqual(result[1], "www.makeit.org") # Server/host name
        self.assertEqual(result[2], "/demo/appl") # Path
        self.assertEqual(result[3], "?input=3") # arguments; could be further deciphered into param=value

        result = crawler.split_url('ftp://user:password@host:port/path') # Our current specs don't cover ftp conns
        self.assertIsInstance(result, list) # Successful queries should also return a list
        self.assertEqual(len(result), 4)
        self.assertEqual(result[0], "ftp") # Protocol
        self.assertEqual(result[1], "user:password@host:port") # Server/Domain name
        self.assertEqual(result[2], "/path") # Path
        self.assertEqual(result[3], None)

        result = crawler.split_url('http://www.makeit.org/?input=3') # Our current specs don't cover ftp conns
        self.assertIsInstance(result, list) # Successful queries should also return a list
        self.assertEqual(len(result), 4)
        self.assertEqual(result[0], "http") # Protocol
        self.assertEqual(result[1], "www.makeit.org") # Server/Domain name
        self.assertEqual(result[2], "/") # Path
        self.assertEqual(result[3], "?input=3")
        # Conclusion: It would be better to use a dict than a list
        # could even populate attributes with specific protocol

if __name__ == '__main__':
    unittest.main()
